@@ -47,7 +47,7 @@
 #include "preferences.h"
 #include "playerctrl.h"
 
-gboolean xmms_plugin_control_new(XfcePanelPlugin *plugin);
+static void xmms_plugin_control_new(XfcePanelPlugin *plugin);
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL(xmms_plugin_control_new);
 
 /******************/
@@ -513,7 +513,8 @@ static void new_button_with_img(GtkWidget *box, gchar *filename, gpointer cb, gp
 /******************************/
 /* creates the plugin widgets */
 /******************************/
-gboolean xmms_plugin_control_new(XfcePanelPlugin *plugin) {
+/* Change type to static void, else doesn't work in Xfce 4.8 */
+static void xmms_plugin_control_new(XfcePanelPlugin *plugin) {
 	GtkWidget *button, *box, *boxV, *boxMain, *pbar, *vol_pbar, *viewport, *eventbox, *label, *menu_btn,*image;
 	plugin_data *pd;
 	gchar *title = TITLE_STRING" +++ "TITLE_STRING" +++ ";
@@ -564,7 +565,7 @@ gboolean xmms_plugin_control_new(XfcePanelPlugin *plugin) {
 		pango_attribute_destroy(pd->labelattr);
 		g_free(pd);
 		gtk_widget_destroy(GTK_WIDGET(plugin));
-		return FALSE;
+		/*return FALSE;*/
 	}
 
 	xfce_panel_plugin_set_expand(plugin,FALSE);
@@ -690,5 +691,5 @@ gboolean xmms_plugin_control_new(XfcePanelPlugin *plugin) {
 
 	pd->timeout                  = g_timeout_add(1000 / pd->scroll_speed, 						pbar_label_update, pd);
 
-	return(TRUE);
+	/*return(TRUE);*/
 }
